[asterisk-commits] russell: branch group/issue_11972 r108320 - in /team/group/issue_11972: ./ ch...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Wed Mar 12 17:23:16 CDT 2008


Author: russell
Date: Wed Mar 12 17:23:15 2008
New Revision: 108320

URL: http://svn.digium.com/view/asterisk?view=rev&rev=108320
Log:
sync with trunk and resolve

Modified:
    team/group/issue_11972/   (props changed)
    team/group/issue_11972/CHANGES
    team/group/issue_11972/channels/chan_sip.c
    team/group/issue_11972/channels/chan_zap.c
    team/group/issue_11972/configs/zapata.conf.sample
    team/group/issue_11972/include/asterisk/http.h
    team/group/issue_11972/include/asterisk/tcptls.h
    team/group/issue_11972/main/http.c
    team/group/issue_11972/main/manager.c
    team/group/issue_11972/main/tcptls.c
    team/group/issue_11972/res/res_phoneprov.c

Propchange: team/group/issue_11972/
------------------------------------------------------------------------------
    automerge = *

Propchange: team/group/issue_11972/
------------------------------------------------------------------------------
Binary property 'branch-1.4-merged' - no diff available.

Propchange: team/group/issue_11972/
------------------------------------------------------------------------------
--- svnmerge-integrated (original)
+++ svnmerge-integrated Wed Mar 12 17:23:15 2008
@@ -1,1 +1,1 @@
-/trunk:1-108238
+/trunk:1-108295

Modified: team/group/issue_11972/CHANGES
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/CHANGES?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/CHANGES (original)
+++ team/group/issue_11972/CHANGES Wed Mar 12 17:23:15 2008
@@ -6,6 +6,11 @@
 ------------------
  * Added a new dialplan function, AST_CONFIG(), which allows you to access
    variables from an Asterisk configuration file.
+
+Zaptel channel driver (chan_zap) Changes
+----------------------------------------
+ * Channels can now be configured using named sections in zapata.conf, just
+   like other channel drivers, including the use of templates.
 
 ------------------------------------------------------------------------------
 --- Functionality changes from Asterisk 1.4.X to Asterisk 1.6.0  -------------

Modified: team/group/issue_11972/channels/chan_sip.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/channels/chan_sip.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/channels/chan_sip.c (original)
+++ team/group/issue_11972/channels/chan_sip.c Wed Mar 12 17:23:15 2008
@@ -776,7 +776,7 @@
 	enum sip_transport type;
 	int fd;
 	uint16_t port;
-	struct ast_tcptls_server_instance *ser;
+	struct ast_tcptls_session_instance *ser;
 };
 
 /*! \brief sip_request: The data grabbed from the UDP socket
@@ -1551,7 +1551,7 @@
 struct sip_threadinfo {
 	int stop;
 	pthread_t threadid;
-	struct ast_tcptls_server_instance *ser;
+	struct ast_tcptls_session_instance *ser;
 	enum sip_transport type;	/* We keep a copy of the type here so we can display it in the connection list */
 	AST_LIST_ENTRY(sip_threadinfo) list;
 };
@@ -2129,17 +2129,17 @@
 	.get_codec = sip_get_codec,
 };
 
-static void *_sip_tcp_helper_thread(struct sip_pvt *pvt, struct ast_tcptls_server_instance *ser);
+static void *_sip_tcp_helper_thread(struct sip_pvt *pvt, struct ast_tcptls_session_instance *ser);
 
 static void *sip_tcp_worker_fn(void *data)
 {
-	struct ast_tcptls_server_instance *ser = data;
+	struct ast_tcptls_session_instance *ser = data;
 
 	return _sip_tcp_helper_thread(NULL, ser);
 }
 
 /*! \brief SIP TCP helper function */
-static void *_sip_tcp_helper_thread(struct sip_pvt *pvt, struct ast_tcptls_server_instance *ser) 
+static void *_sip_tcp_helper_thread(struct sip_pvt *pvt, struct ast_tcptls_session_instance *ser) 
 {
 	int res, cl;
 	struct sip_request req = { 0, } , reqcpy = { 0, };
@@ -4185,7 +4185,8 @@
 		p->invitestate = INV_CALLING;
 	
 		/* Initialize auto-congest time */
-		AST_SCHED_REPLACE(p->initid, sched, p->timer_b, auto_congest, dialog_ref(p));
+		ast_sched_del(sched, p->initid);
+		p->initid = ast_sched_add(sched, p->timer_b, auto_congest, dialog_ref(p));
 	}
 
 	return res;
@@ -4254,7 +4255,7 @@
 
 	if (p->stateid > -1)
 		ast_extension_state_del(p->stateid, NULL);
-	AST_SCHED_DEL(sched, p->initid);
+	ast_sched_del(sched, p->initid);
 	AST_SCHED_DEL(sched, p->waitid);
 	AST_SCHED_DEL(sched, p->autokillid);
 
@@ -14459,7 +14460,7 @@
 
 	/* Acknowledge sequence number - This only happens on INVITE from SIP-call */
 	/* Don't auto congest anymore since we've gotten something useful back */
-	AST_SCHED_DEL(sched, p->initid);
+	ast_sched_del(sched, p->initid);
 
 	/* RFC3261 says we must treat every 1xx response (but not 100)
 	   that we don't recognize as if it was 183.
@@ -18085,7 +18086,7 @@
 }
 
 /*! \todo document this function. */
-static struct ast_tcptls_server_instance *sip_tcp_locate(struct sockaddr_in *s)
+static struct ast_tcptls_session_instance *sip_tcp_locate(struct sockaddr_in *s)
 {
 	struct sip_threadinfo *th;
 
@@ -18107,7 +18108,7 @@
 {
 	struct sip_socket *s = &p->socket;
 	static const char name[] = "SIP socket";
-	struct ast_tcptls_server_instance *ser;
+	struct ast_tcptls_session_instance *ser;
 	struct server_args ca = {
 		.name = name,
 		.accept_fd = -1,

Modified: team/group/issue_11972/channels/chan_zap.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/channels/chan_zap.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/channels/chan_zap.c (original)
+++ team/group/issue_11972/channels/chan_zap.c Wed Mar 12 17:23:15 2008
@@ -13196,7 +13196,12 @@
 }
 #endif /* defined(HAVE_ZAPTEL_ECHOCANPARAMS) */
 
-static int process_zap(struct zt_chan_conf *confp, struct ast_variable *v, int reload, int skipchannels)
+/*! process_zap() - ignore keyword 'channel' and similar */
+#define PROC_ZAP_OPT_NOCHAN  (1 << 0) 
+/*! process_zap() - No warnings on non-existing cofiguration keywords */
+#define PROC_ZAP_OPT_NOWARN  (1 << 1) 
+
+static int process_zap(struct zt_chan_conf *confp, struct ast_variable *v, int reload, int options)
 {
 	struct zt_pvt *tmp;
 	const char *ringc; /* temporary string for parsing the dring number. */
@@ -13215,7 +13220,7 @@
 #endif			
 			) {
  			int iscrv;
- 			if (skipchannels)
+ 			if (options && PROC_ZAP_OPT_NOCHAN)
  				continue;
  			iscrv = !strcasecmp(v->name, "crv");
  			if (build_channels(*confp, iscrv, v->value, reload, v->lineno, &found_pseudo))
@@ -13960,7 +13965,7 @@
 			} else if (!strcasecmp(v->name, "mwilevel")) {
 				mwilevel = atoi(v->value);
 			}
-		} else if (!skipchannels)
+		} else if (!(options && PROC_ZAP_OPT_NOWARN) )
 			ast_log(LOG_WARNING, "Ignoring %s at line %d.\n", v->name, v->lineno);
 	}
 	if (zapchan[0]) { 
@@ -13998,6 +14003,7 @@
  	struct zt_chan_conf base_conf = zt_chan_conf_default();
  	struct zt_chan_conf conf;
 	struct ast_flags config_flags = { reload == 1 ? CONFIG_FLAG_FILEUNCHANGED : 0 };
+	const char *cat;
 	int res;
 
 #ifdef HAVE_PRI
@@ -14090,35 +14096,74 @@
 #endif
 	
 	/* Copy the default jb config over global_jbconf */
-	memcpy(&global_jbconf, &default_jbconf, sizeof(struct ast_jb_conf));
+	memcpy(&global_jbconf, &default_jbconf, sizeof(global_jbconf));
 
 	mwimonitornotify[0] = '\0';
 
 	v = ast_variable_browse(cfg, "channels");
-	res = process_zap(&base_conf, v, reload, 0);
+	if ((res = process_zap(&base_conf, v, reload, 0))) {
+		ast_mutex_unlock(&iflock);
+		ast_config_destroy(cfg);
+		if (ucfg) {
+			ast_config_destroy(cfg);
+		}
+		return res;
+	}
+
+	/* Now get configuration from all normal sections in zapata.conf: */
+	for (cat = ast_category_browse(cfg, NULL); cat ; cat = ast_category_browse(cfg, cat)) {
+		/* [channels] and [trunkgroups] are used. Let's also reserve
+		 * [globals] and [general] for future use
+		 */
+		if (!strcasecmp(cat, "general") || 
+		    !strcasecmp(cat, "trunkgroups") ||
+		    !strcasecmp(cat, "globals") ||
+		    !strcasecmp(cat, "channels")) {
+			continue;
+		}
+
+		memcpy(&conf, &base_conf, sizeof(conf));
+
+		if ((res = process_zap(&conf, ast_variable_browse(cfg, cat), reload, PROC_ZAP_OPT_NOCHAN))) {
+			ast_mutex_unlock(&iflock);
+			ast_config_destroy(cfg);
+			if (ucfg) {
+				ast_config_destroy(cfg);
+			}
+			return res;
+		}
+	}
+
+	ast_config_destroy(cfg);
+
+	if (ucfg) {
+		const char *chans;
+
+		process_zap(&base_conf, ast_variable_browse(ucfg, "general"), 1, 0);
+
+		for (cat = ast_category_browse(ucfg, NULL); cat ; cat = ast_category_browse(ucfg, cat)) {
+			if (!strcasecmp(cat, "general")) {
+				continue;
+			}
+
+			chans = ast_variable_retrieve(ucfg, cat, "zapchan");
+
+			if (ast_strlen_zero(chans)) {
+				continue;
+			}
+
+			memcpy(&conf, &base_conf, sizeof(conf));
+
+			if ((res = process_zap(&conf, ast_variable_browse(ucfg, cat), reload, PROC_ZAP_OPT_NOCHAN | PROC_ZAP_OPT_NOWARN))) {
+				ast_config_destroy(ucfg);
+				ast_mutex_unlock(&iflock);
+				return res;
+			}
+		}
+		ast_config_destroy(ucfg);
+	}
 	ast_mutex_unlock(&iflock);
-	ast_config_destroy(cfg);
-	if (res)
-		return res;
-	if (ucfg) {
-		char *cat;
-		const char *chans;
-		process_zap(&base_conf, ast_variable_browse(ucfg, "general"), 1, 1);
-		for (cat = ast_category_browse(ucfg, NULL); cat ; cat = ast_category_browse(ucfg, cat)) {
-			if (!strcasecmp(cat, "general"))
-				continue;
-			chans = ast_variable_retrieve(ucfg, cat, "zapchan");
-			if (!ast_strlen_zero(chans)) {
-				if (memcpy(&conf, &base_conf, sizeof(conf)) == NULL) {
-					ast_log(LOG_ERROR, "Not enough memory for conf copy\n");
-					ast_config_destroy(ucfg);
-					return -1;
-				}
-				process_zap(&conf, ast_variable_browse(ucfg, cat), reload, 0);
-			}
-		}
-		ast_config_destroy(ucfg);
-	}
+
 #ifdef HAVE_PRI
 	if (!reload) {
 		int x;

Modified: team/group/issue_11972/configs/zapata.conf.sample
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/configs/zapata.conf.sample?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/configs/zapata.conf.sample (original)
+++ team/group/issue_11972/configs/zapata.conf.sample Wed Mar 12 17:23:15 2008
@@ -915,3 +915,57 @@
 ; For more information on setting up SS7, see the README file in libss7 or
 ; the doc/ss7.txt file in the Asterisk source tree.
 ; ----------------- SS7 Options ----------------------------------------
+
+; Configuration Sections
+; ~~~~~~~~~~~~~~~~~~~~~~
+; You can also configure channels in a separate zapata.conf section. In
+; this case the keyword 'channel' is not used. Instead the keyword
+; 'zapchan' is used (as in users.conf) - configuration is only processed
+; in a section where the keyword zapchan is used. It will only be
+; processed in the end of the section. Thus the following section:
+;
+;[phones]
+;echocancel = 64
+;zapchan = 1-8
+;group = 1
+;
+; Is somewhat equivalent to the following snippet in the section
+; [channels]:
+;
+;echocancel = 64
+;group = 1
+;channel => 1-8
+;
+; When starting a new section almost all of the configuration values are
+; copied from their values at the end of the section [channels] in
+; zapata.conf and [general] in users.conf - one section's configuration
+; does not affect another one's.
+;
+; Instead of letting common configuration values "slide through" you can 
+; use configuration templates to easily keep the common part in one
+; place and override where needed.
+;
+;[phones](!)
+;echocancel = yes
+;group = 0,4
+;callgroup = 3
+;pickupgroup = 3
+;threewaycalling = yes
+;transfer = yes
+;context = phones
+;faxdetect = incoming
+;
+;[phone-1](phones)
+;zapchan = 1
+;callerid = My Name <501>
+;mailbox = 501 at mailboxes
+;
+;
+;[fax](phones)
+;zapchan = 2
+;faxdetect = no
+;context = fax
+;
+;[phone-3](phones)
+;zapchan = 3
+;pickupgroup = 3,4

Modified: team/group/issue_11972/include/asterisk/http.h
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/include/asterisk/http.h?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/include/asterisk/http.h (original)
+++ team/group/issue_11972/include/asterisk/http.h Wed Mar 12 17:23:15 2008
@@ -65,7 +65,7 @@
    content is specified) 
 \endverbatim
 */
-typedef struct ast_str *(*ast_http_callback)(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
+typedef struct ast_str *(*ast_http_callback)(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
 
 /*! \brief Definition of a URI reachable in the embedded HTTP server */
 struct ast_http_uri {

Modified: team/group/issue_11972/include/asterisk/tcptls.h
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/include/asterisk/tcptls.h?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/main/http.c (original)
+++ team/group/issue_11972/main/http.c Wed Mar 12 17:23:15 2008
@@ -137,7 +137,7 @@
 	return wkspace;
 }
 
-static struct ast_str *static_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
+static struct ast_str *static_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
 {
 	char *path;
 	char *ftype;
@@ -207,7 +207,7 @@
 }
 
 
-static struct ast_str *httpstatus_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
+static struct ast_str *httpstatus_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
 {
 	struct ast_str *out = ast_str_create(512);
 	struct ast_variable *v;
@@ -392,7 +392,7 @@
 	fclose(f);
 }
 
-static struct ast_str *handle_post(struct ast_tcptls_server_instance *ser, char *uri, 
+static struct ast_str *handle_post(struct ast_tcptls_session_instance *ser, char *uri, 
 	int *status, char **title, int *contentlength, struct ast_variable *headers,
 	struct ast_variable *cookies)
 {
@@ -535,7 +535,7 @@
 	return ast_http_error(200, "OK", NULL, "File successfully uploaded.");
 }
 
-static struct ast_str *handle_uri(struct ast_tcptls_server_instance *ser, char *uri, int *status, 
+static struct ast_str *handle_uri(struct ast_tcptls_session_instance *ser, char *uri, int *status, 
 	char **title, int *contentlength, struct ast_variable **cookies, 
 	unsigned int *static_content)
 {
@@ -683,7 +683,7 @@
 {
 	char buf[4096];
 	char cookie[4096];
-	struct ast_tcptls_server_instance *ser = data;
+	struct ast_tcptls_session_instance *ser = data;
 	struct ast_variable *var, *prev=NULL, *vars=NULL, *headers = NULL;
 	char *uri, *title=NULL;
 	int status = 200, contentlength = 0;

Modified: team/group/issue_11972/main/manager.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/main/manager.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/main/manager.c (original)
+++ team/group/issue_11972/main/manager.c Wed Mar 12 17:23:15 2008
@@ -2887,7 +2887,7 @@
  */
 static void *session_do(void *data)
 {
-	struct ast_tcptls_server_instance *ser = data;
+	struct ast_tcptls_session_instance *ser = data;
 	struct mansession *s = ast_calloc(1, sizeof(*s));
 	int flags;
 	int res;
@@ -3632,17 +3632,17 @@
 	return out;
 }
 
-static struct ast_str *manager_http_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
+static struct ast_str *manager_http_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
 {
 	return generic_http_callback(FORMAT_HTML, &ser->requestor, uri, params, status, title, contentlength);
 }
 
-static struct ast_str *mxml_http_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
+static struct ast_str *mxml_http_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
 {
 	return generic_http_callback(FORMAT_XML, &ser->requestor, uri, params, status, title, contentlength);
 }
 
-static struct ast_str *rawman_http_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
+static struct ast_str *rawman_http_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength)
 {
 	return generic_http_callback(FORMAT_RAW, &ser->requestor, uri, params, status, title, contentlength);
 }

Modified: team/group/issue_11972/main/tcptls.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/main/tcptls.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/main/tcptls.c (original)
+++ team/group/issue_11972/main/tcptls.c Wed Mar 12 17:23:15 2008
@@ -81,7 +81,7 @@
 }
 #endif	/* DO_SSL */
 
-HOOK_T ast_tcptls_server_read(struct ast_tcptls_server_instance *ser, void *buf, size_t count)
+HOOK_T ast_tcptls_server_read(struct ast_tcptls_session_instance *ser, void *buf, size_t count)
 {
 	if (ser->fd == -1) {
 		ast_log(LOG_ERROR, "server_read called with an fd of -1\n");
@@ -96,7 +96,7 @@
 	return read(ser->fd, buf, count);
 }
 
-HOOK_T ast_tcptls_server_write(struct ast_tcptls_server_instance *ser, void *buf, size_t count)
+HOOK_T ast_tcptls_server_write(struct ast_tcptls_session_instance *ser, void *buf, size_t count)
 {
 	if (ser->fd == -1) {
 		ast_log(LOG_ERROR, "server_write called with an fd of -1\n");
@@ -111,9 +111,9 @@
 	return write(ser->fd, buf, count);
 }
 
-static void server_instance_destructor(void *obj)
-{
-	struct ast_tcptls_server_instance *i = obj;
+static void session_instance_destructor(void *obj)
+{
+	struct ast_tcptls_session_instance *i = obj;
 	ast_mutex_destroy(&i->lock);
 }
 
@@ -123,7 +123,7 @@
 	int fd;
 	struct sockaddr_in sin;
 	socklen_t sinlen;
-	struct ast_tcptls_server_instance *ser;
+	struct ast_tcptls_session_instance *ser;
 	pthread_t launched;
 	
 	for (;;) {
@@ -141,7 +141,7 @@
 				ast_log(LOG_WARNING, "Accept failed: %s\n", strerror(errno));
 			continue;
 		}
-		ser = ao2_alloc(sizeof(*ser), server_instance_destructor);
+		ser = ao2_alloc(sizeof(*ser), session_instance_destructor);
 		if (!ser) {
 			ast_log(LOG_WARNING, "No memory for new session: %s\n", strerror(errno));
 			close(fd);
@@ -225,10 +225,10 @@
 /*! \brief A generic client routine for a TCP client
  *  and starts a thread for handling accept()
  */
-struct ast_tcptls_server_instance *ast_tcptls_client_start(struct server_args *desc)
+struct ast_tcptls_session_instance *ast_tcptls_client_start(struct server_args *desc)
 {
 	int flags;
-	struct ast_tcptls_server_instance *ser = NULL;
+	struct ast_tcptls_session_instance *ser = NULL;
 
 	/* Do nothing if nothing has changed */
 	if(!memcmp(&desc->oldsin, &desc->sin, sizeof(desc->oldsin))) {
@@ -256,7 +256,7 @@
 		goto error;
 	}
 
-	if (!(ser = ao2_alloc(sizeof(*ser), server_instance_destructor)))
+	if (!(ser = ao2_alloc(sizeof(*ser), session_instance_destructor)))
 		goto error;
 
 	ast_mutex_init(&ser->lock);
@@ -376,7 +376,7 @@
 */
 void *ast_make_file_from_fd(void *data)
 {
-	struct ast_tcptls_server_instance *ser = data;
+	struct ast_tcptls_session_instance *ser = data;
 #ifdef DO_SSL
 	int (*ssl_setup)(SSL *) = (ser->client) ? SSL_connect : SSL_accept;
 	int ret;
@@ -470,4 +470,3 @@
 		return ser;
 }
 
-

Modified: team/group/issue_11972/res/res_phoneprov.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/res/res_phoneprov.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================
--- team/group/issue_11972/res/res_phoneprov.c (original)
+++ team/group/issue_11972/res/res_phoneprov.c Wed Mar 12 17:23:15 2008
@@ -323,7 +323,7 @@
 }
 
 /*! \brief Callback that is executed everytime an http request is received by this module */
-static struct ast_str *phoneprov_callback(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
+static struct ast_str *phoneprov_callback(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *vars, int *status, char **title, int *contentlength)
 {
 	struct http_route *route;
 	struct http_route search_route = {




More information about the asterisk-commits mailing list
--- team/group/issue_11972/include/asterisk/tcptls.h (original)
+++ team/group/issue_11972/include/asterisk/tcptls.h Wed Mar 12 17:23:15 2008
@@ -103,7 +103,7 @@
  * or equivalent with a timeout of 'poll_timeout' milliseconds, and if the
  * following accept() is successful it creates a thread in charge of
  * running the session, whose body is desc->worker_fn(). The argument of
  * worker_fn() is a struct ast_tcptls_server_instance, which contains the address
  * of the other party, a pointer to desc, the file descriptors (fd) on which
  * we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
  * We have both because we want to support plain and SSL sockets, and
@@ -112,7 +112,7 @@
  *
  * NOTE: in order to let other parts of asterisk use these services,
  * we need to do the following:
  * + move struct ast_tcptls_server_instance and struct server_args to
  * a common header file, together with prototypes for
  * server_start() and server_root().
  */
@@ -120,7 +120,7 @@
 /*! \brief
  * describes a server instance
  */
-struct ast_tcptls_server_instance {
+struct ast_tcptls_session_instance {
 	FILE *f;    /* fopen/funopen result */
 	int fd;     /* the socket returned by accept() */
 	SSL *ssl;   /* ssl state */
@@ -156,7 +156,7 @@
 #define LEN_T size_t
 #endif
 
-struct ast_tcptls_server_instance *ast_tcptls_client_start(struct server_args *desc);
+struct ast_tcptls_session_instance *ast_tcptls_client_start(struct server_args *desc);
 
 void *ast_tcptls_server_root(void *);
 void ast_tcptls_server_start(struct server_args *desc);
@@ -165,7 +165,7 @@
 
 void *ast_make_file_from_fd(void *data);
 
-HOOK_T ast_tcptls_server_read(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
-HOOK_T ast_tcptls_server_write(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
+HOOK_T ast_tcptls_server_read(struct ast_tcptls_session_instance *ser, void *buf, size_t count);
+HOOK_T ast_tcptls_server_write(struct ast_tcptls_session_instance *ser, void *buf, size_t count);
 
 #endif /* _ASTERISK_SERVER_H */
@@ -103,7 +103,7 @@
  * following accept() is successful it creates a thread in charge of
  * running the session, whose body is desc->worker_fn(). The argument of
- * worker_fn() is a struct ast_tcptls_server_instance, which contains the address
+ * worker_fn() is a struct ast_tcptls_session_instance, which contains the address
  * of the other party, a pointer to desc, the file descriptors (fd) on which
  * we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
@@ -112,7 +112,7 @@
  * NOTE: in order to let other parts of asterisk use these services,
  * we need to do the following:
- * + move struct ast_tcptls_server_instance and struct server_args to
+ * + move struct ast_tcptls_session_instance and struct server_args to
  * a common header file, together with prototypes for
  * server_start() and server_root().

Modified: team/group/issue_11972/main/http.c
URL: http://svn.digium.com/view/asterisk/team/group/issue_11972/main/http.c?view=diff&rev=108320&r1=108319&r2=108320
==============================================================================